pub struct FilterRequest {
pub request_id: Box<str>,
pub thread_id: Option<Box<str>>,
pub method: Box<str>,
pub path: Box<str>,
pub query: Option<Box<str>>,
pub headers: Box<[Header]>,
pub body: Box<[u8]>,
pub principal: Principal,
pub candidates: Box<[UpstreamCandidate]>,
}Expand description
Filter hook input (owned form used by the guest).
Fields
request_id: Box<str>thread_id: Option<Box<str>>method: Box<str>path: Box<str>query: Option<Box<str>>headers: Box<[Header]>body: Box<[u8]>principal: Principalcandidates: Box<[UpstreamCandidate]>Trait Implementations
Sourceimpl Archive for FilterRequest
impl Archive for FilterRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedFilterRequest
type Archived = ArchivedFilterRequest
The archived representation of this type. Read more
Sourcetype Resolver = FilterRequestResolver
type Resolver = FilterRequestResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for FilterRequest
impl Clone for FilterRequest
Sourcefn clone(&self) -> FilterRequest
fn clone(&self) -> FilterRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FilterRequest
impl Debug for FilterRequest
Sourceimpl<__D: Fallible + ?Sized> Deserialize<FilterRequest, __D> for Archived<FilterRequest>where
Box<str>: Archive,
<Box<str> as Archive>::Archived: Deserialize<Box<str>, __D>,
Option<Box<str>>: Archive,
<Option<Box<str>> as Archive>::Archived: Deserialize<Option<Box<str>>, __D>,
Box<[Header]>: Archive,
<Box<[Header]> as Archive>::Archived: Deserialize<Box<[Header]>, __D>,
Box<[u8]>: Archive,
<Box<[u8]> as Archive>::Archived: Deserialize<Box<[u8]>, __D>,
Principal: Archive,
<Principal as Archive>::Archived: Deserialize<Principal, __D>,
Box<[UpstreamCandidate]>: Archive,
<Box<[UpstreamCandidate]> as Archive>::Archived: Deserialize<Box<[UpstreamCandidate]>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<FilterRequest, __D> for Archived<FilterRequest>where
Box<str>: Archive,
<Box<str> as Archive>::Archived: Deserialize<Box<str>, __D>,
Option<Box<str>>: Archive,
<Option<Box<str>> as Archive>::Archived: Deserialize<Option<Box<str>>, __D>,
Box<[Header]>: Archive,
<Box<[Header]> as Archive>::Archived: Deserialize<Box<[Header]>, __D>,
Box<[u8]>: Archive,
<Box<[u8]> as Archive>::Archived: Deserialize<Box<[u8]>, __D>,
Principal: Archive,
<Principal as Archive>::Archived: Deserialize<Principal, __D>,
Box<[UpstreamCandidate]>: Archive,
<Box<[UpstreamCandidate]> as Archive>::Archived: Deserialize<Box<[UpstreamCandidate]>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<FilterRequest, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<FilterRequest, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl WireSchema for FilterRequest
impl WireSchema for FilterRequest
const FINGERPRINT: [u8; 32]
const DESCRIPTOR: &'static str = "FilterRequest{body:Box<[u8]>,candidates:Box<[UpstreamCandidate]>,headers:Box<[Header]>,method:Box<str>,path:Box<str>,principal:Principal,query:Option<Box<str>>,request_id:Box<str>,thread_id:Option<Box<str>>}"