pub struct FilterRequestRef<'a> {
pub request_id: &'a str,
pub thread_id: Option<QueryRef<'a>>,
pub method: &'a str,
pub path: &'a str,
pub query: Option<QueryRef<'a>>,
pub headers: &'a [HeaderRef<'a>],
pub body: &'a [u8],
pub principal: PrincipalRef<'a>,
pub candidates: &'a [UpstreamCandidateRef<'a>],
}Expand description
Borrowed mirror of FilterRequest used by the host encode path.
Serialising this emits the same archived byte layout as
FilterRequest so the guest reads it via
rkyv::access::<ArchivedFilterRequest, _> unchanged.
Fields
request_id: &'a strthread_id: Option<QueryRef<'a>>method: &'a strpath: &'a strquery: Option<QueryRef<'a>>headers: &'a [HeaderRef<'a>]body: &'a [u8]principal: PrincipalRef<'a>candidates: &'a [UpstreamCandidateRef<'a>]Trait Implementations
Sourceimpl<'a> Archive for FilterRequestRef<'a>where
InlineAsBox: ArchiveWith<&'a str> + ArchiveWith<&'a [HeaderRef<'a>]> + ArchiveWith<&'a [u8]> + ArchiveWith<&'a [UpstreamCandidateRef<'a>]>,
Option<QueryRef<'a>>: Archive,
PrincipalRef<'a>: Archive,
impl<'a> Archive for FilterRequestRef<'a>where
InlineAsBox: ArchiveWith<&'a str> + ArchiveWith<&'a [HeaderRef<'a>]> + ArchiveWith<&'a [u8]> + ArchiveWith<&'a [UpstreamCandidateRef<'a>]>,
Option<QueryRef<'a>>: Archive,
PrincipalRef<'a>: Archive,
Sourcetype Archived = ArchivedFilterRequestRef<'a>
type Archived = ArchivedFilterRequestRef<'a>
The archived representation of this type. Read more
Sourcetype Resolver = FilterRequestRefResolver<'a>
type Resolver = FilterRequestRefResolver<'a>
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl<'a, __S: Fallible + ?Sized> Serialize<__S> for FilterRequestRef<'a>where
InlineAsBox: SerializeWith<&'a str, __S> + SerializeWith<&'a [HeaderRef<'a>], __S> + SerializeWith<&'a [u8], __S> + SerializeWith<&'a [UpstreamCandidateRef<'a>], __S>,
Option<QueryRef<'a>>: Serialize<__S>,
PrincipalRef<'a>: Serialize<__S>,
impl<'a, __S: Fallible + ?Sized> Serialize<__S> for FilterRequestRef<'a>where
InlineAsBox: SerializeWith<&'a str, __S> + SerializeWith<&'a [HeaderRef<'a>], __S> + SerializeWith<&'a [u8], __S> + SerializeWith<&'a [UpstreamCandidateRef<'a>], __S>,
Option<QueryRef<'a>>: Serialize<__S>,
PrincipalRef<'a>: Serialize<__S>,
impl<'a> WireSchema for FilterRequestRef<'a>
impl<'a> WireSchema for FilterRequestRef<'a>
const FINGERPRINT: [u8; 32]
const DESCRIPTOR: &'static str = "FilterRequestRef{body:&[u8],candidates:&[UpstreamCandidateRef],headers:&[HeaderRef],method:&str,path:&str,principal:PrincipalRef,query:Option<QueryRef>,request_id:&str,thread_id:Option<QueryRef>}"