pub struct HeaderRef<'a> {
pub name: &'a str,
pub value: &'a [u8],
}Expand description
Borrowed mirror of Header.
Fields
name: &'a strvalue: &'a [u8]Trait Implementations
Sourceimpl<'a> Archive for HeaderRef<'a>
impl<'a> Archive for HeaderRef<'a>
Sourcetype Archived = ArchivedHeaderRef<'a>
type Archived = ArchivedHeaderRef<'a>
The archived representation of this type. Read more
Sourcetype Resolver = HeaderRefResolver<'a>
type Resolver = HeaderRefResolver<'a>
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreimpl<'a> WireSchema for HeaderRef<'a>
impl<'a> WireSchema for HeaderRef<'a>
const FINGERPRINT: [u8; 32]
const DESCRIPTOR: &'static str = "HeaderRef{name:&str,value:&[u8]}"