pub struct ShapeRequest {
pub request_id: Box<str>,
pub method: Box<str>,
pub path: Box<str>,
pub query: Option<Box<str>>,
pub headers: Box<[Header]>,
pub body: Box<[u8]>,
pub principal: Principal,
pub upstream: Upstream,
}Expand description
Shape hook input (owned form).
Fields
request_id: Box<str>method: Box<str>path: Box<str>query: Option<Box<str>>headers: Box<[Header]>body: Box<[u8]>principal: Principalupstream: UpstreamTrait Implementations
Sourceimpl Archive for ShapeRequest
impl Archive for ShapeRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedShapeRequest
type Archived = ArchivedShapeRequest
The archived representation of this type. Read more
Sourcetype Resolver = ShapeRequestResolver
type Resolver = ShapeRequestResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ShapeRequest
impl Clone for ShapeRequest
Sourcefn clone(&self) -> ShapeRequest
fn clone(&self) -> ShapeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShapeRequest
impl Debug for ShapeRequest
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ShapeRequest, __D> for Archived<ShapeRequest>where
Box<str>: Archive,
<Box<str> as Archive>::Archived: Deserialize<Box<str>, __D>,
Option<Box<str>>: Archive,
<Option<Box<str>> as Archive>::Archived: Deserialize<Option<Box<str>>, __D>,
Box<[Header]>: Archive,
<Box<[Header]> as Archive>::Archived: Deserialize<Box<[Header]>, __D>,
Box<[u8]>: Archive,
<Box<[u8]> as Archive>::Archived: Deserialize<Box<[u8]>, __D>,
Principal: Archive,
<Principal as Archive>::Archived: Deserialize<Principal, __D>,
Upstream: Archive,
<Upstream as Archive>::Archived: Deserialize<Upstream, __D>,
impl<__D: Fallible + ?Sized> Deserialize<ShapeRequest, __D> for Archived<ShapeRequest>where
Box<str>: Archive,
<Box<str> as Archive>::Archived: Deserialize<Box<str>, __D>,
Option<Box<str>>: Archive,
<Option<Box<str>> as Archive>::Archived: Deserialize<Option<Box<str>>, __D>,
Box<[Header]>: Archive,
<Box<[Header]> as Archive>::Archived: Deserialize<Box<[Header]>, __D>,
Box<[u8]>: Archive,
<Box<[u8]> as Archive>::Archived: Deserialize<Box<[u8]>, __D>,
Principal: Archive,
<Principal as Archive>::Archived: Deserialize<Principal, __D>,
Upstream: Archive,
<Upstream as Archive>::Archived: Deserialize<Upstream, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ShapeRequest, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ShapeRequest, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl WireSchema for ShapeRequest
impl WireSchema for ShapeRequest
const FINGERPRINT: [u8; 32]
const DESCRIPTOR: &'static str = "ShapeRequest{body:Box<[u8]>,headers:Box<[Header]>,method:Box<str>,path:Box<str>,principal:Principal,query:Option<Box<str>>,request_id:Box<str>,upstream:Upstream}"