pub struct ShapeResponse {
pub url: Box<str>,
pub method: Box<str>,
pub headers: Box<[Header]>,
pub body: Box<[u8]>,
}Expand description
Shape hook output — the upstream-bound request the plugin produced.
Fields
url: Box<str>method: Box<str>headers: Box<[Header]>body: Box<[u8]>Trait Implementations
Sourceimpl Archive for ShapeResponse
impl Archive for ShapeResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedShapeResponse
type Archived = ArchivedShapeResponse
The archived representation of this type. Read more
Sourcetype Resolver = ShapeResponseResolver
type Resolver = ShapeResponseResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ShapeResponse
impl Clone for ShapeResponse
Sourcefn clone(&self) -> ShapeResponse
fn clone(&self) -> ShapeResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShapeResponse
impl Debug for ShapeResponse
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ShapeResponse, __D> for Archived<ShapeResponse>
impl<__D: Fallible + ?Sized> Deserialize<ShapeResponse, __D> for Archived<ShapeResponse>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ShapeResponse, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ShapeResponse, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl WireSchema for ShapeResponse
impl WireSchema for ShapeResponse
const FINGERPRINT: [u8; 32]
const DESCRIPTOR: &'static str = "ShapeResponse{body:Box<[u8]>,headers:Box<[Header]>,method:Box<str>,url:Box<str>}"