pub struct TransformResponseRequest {
pub request_id: Box<str>,
pub principal: Principal,
pub upstream: Upstream,
pub request_method: Box<str>,
pub request_path: Box<str>,
pub canonical_model_id: Box<str>,
pub response_status: u16,
pub response_headers: Box<[Header]>,
pub body: Box<[u8]>,
}Fields
request_id: Box<str>principal: Principalupstream: Upstreamrequest_method: Box<str>request_path: Box<str>canonical_model_id: Box<str>response_status: u16response_headers: Box<[Header]>body: Box<[u8]>Trait Implementations
Sourceimpl Archive for TransformResponseRequest
impl Archive for TransformResponseRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedTransformResponseRequest
type Archived = ArchivedTransformResponseRequest
The archived representation of this type. Read more
Sourcetype Resolver = TransformResponseRequestResolver
type Resolver = TransformResponseRequestResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for TransformResponseRequest
impl Clone for TransformResponseRequest
Sourcefn clone(&self) -> TransformResponseRequest
fn clone(&self) -> TransformResponseRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransformResponseRequest
impl Debug for TransformResponseRequest
Sourceimpl<__D: Fallible + ?Sized> Deserialize<TransformResponseRequest, __D> for Archived<TransformResponseRequest>where
Box<str>: Archive,
<Box<str> as Archive>::Archived: Deserialize<Box<str>, __D>,
Principal: Archive,
<Principal as Archive>::Archived: Deserialize<Principal, __D>,
Upstream: Archive,
<Upstream as Archive>::Archived: Deserialize<Upstream, __D>,
u16: Archive,
<u16 as Archive>::Archived: Deserialize<u16, __D>,
Box<[Header]>: Archive,
<Box<[Header]> as Archive>::Archived: Deserialize<Box<[Header]>, __D>,
Box<[u8]>: Archive,
<Box<[u8]> as Archive>::Archived: Deserialize<Box<[u8]>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<TransformResponseRequest, __D> for Archived<TransformResponseRequest>where
Box<str>: Archive,
<Box<str> as Archive>::Archived: Deserialize<Box<str>, __D>,
Principal: Archive,
<Principal as Archive>::Archived: Deserialize<Principal, __D>,
Upstream: Archive,
<Upstream as Archive>::Archived: Deserialize<Upstream, __D>,
u16: Archive,
<u16 as Archive>::Archived: Deserialize<u16, __D>,
Box<[Header]>: Archive,
<Box<[Header]> as Archive>::Archived: Deserialize<Box<[Header]>, __D>,
Box<[u8]>: Archive,
<Box<[u8]> as Archive>::Archived: Deserialize<Box<[u8]>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<TransformResponseRequest, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<TransformResponseRequest, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl WireSchema for TransformResponseRequest
impl WireSchema for TransformResponseRequest
const FINGERPRINT: [u8; 32]
const DESCRIPTOR: &'static str = "TransformResponseRequest{body:Box<[u8]>,canonical_model_id:Box<str>,principal:Principal,request_id:Box<str>,request_method:Box<str>,request_path:Box<str>,response_headers:Box<[Header]>,response_status:u16,upstream:Upstream}"