pub struct TransformSseEventRequestRef<'a> {
pub request_id: &'a str,
pub principal: PrincipalRef<'a>,
pub upstream: UpstreamRef<'a>,
pub request_method: &'a str,
pub request_path: &'a str,
pub canonical_model_id: &'a str,
pub response_status: u16,
pub response_headers: &'a [HeaderRef<'a>],
pub event: SseEventRef<'a>,
}Fields
request_id: &'a strprincipal: PrincipalRef<'a>upstream: UpstreamRef<'a>request_method: &'a strrequest_path: &'a strcanonical_model_id: &'a strresponse_status: u16response_headers: &'a [HeaderRef<'a>]event: SseEventRef<'a>Trait Implementations
Sourceimpl<'a> Archive for TransformSseEventRequestRef<'a>where
InlineAsBox: ArchiveWith<&'a str> + ArchiveWith<&'a [HeaderRef<'a>]>,
PrincipalRef<'a>: Archive,
UpstreamRef<'a>: Archive,
u16: Archive,
SseEventRef<'a>: Archive,
impl<'a> Archive for TransformSseEventRequestRef<'a>where
InlineAsBox: ArchiveWith<&'a str> + ArchiveWith<&'a [HeaderRef<'a>]>,
PrincipalRef<'a>: Archive,
UpstreamRef<'a>: Archive,
u16: Archive,
SseEventRef<'a>: Archive,
Sourcetype Archived = ArchivedTransformSseEventRequestRef<'a>
type Archived = ArchivedTransformSseEventRequestRef<'a>
The archived representation of this type. Read more
Sourcetype Resolver = TransformSseEventRequestRefResolver<'a>
type Resolver = TransformSseEventRequestRefResolver<'a>
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl<'a, __S: Fallible + ?Sized> Serialize<__S> for TransformSseEventRequestRef<'a>where
InlineAsBox: SerializeWith<&'a str, __S> + SerializeWith<&'a [HeaderRef<'a>], __S>,
PrincipalRef<'a>: Serialize<__S>,
UpstreamRef<'a>: Serialize<__S>,
u16: Serialize<__S>,
SseEventRef<'a>: Serialize<__S>,
impl<'a, __S: Fallible + ?Sized> Serialize<__S> for TransformSseEventRequestRef<'a>where
InlineAsBox: SerializeWith<&'a str, __S> + SerializeWith<&'a [HeaderRef<'a>], __S>,
PrincipalRef<'a>: Serialize<__S>,
UpstreamRef<'a>: Serialize<__S>,
u16: Serialize<__S>,
SseEventRef<'a>: Serialize<__S>,
impl<'a> WireSchema for TransformSseEventRequestRef<'a>
impl<'a> WireSchema for TransformSseEventRequestRef<'a>
const FINGERPRINT: [u8; 32]
const DESCRIPTOR: &'static str = "TransformSseEventRequestRef{canonical_model_id:&str,event:SseEventRef,principal:PrincipalRef,request_id:&str,request_method:&str,request_path:&str,response_headers:&[HeaderRef],response_status:u16,upstream:UpstreamRef}"