pub struct UpstreamCandidate {
pub upstream_id: Box<str>,
pub name: Box<str>,
pub kind: Box<str>,
pub observed_at_unix_secs: u64,
pub predicted_cache_read_tokens: u32,
pub plan_capacity_ratio: f64,
pub organization_type: Box<str>,
pub rate_limit_tier: Box<str>,
pub seat_tier: Box<str>,
}Expand description
One upstream candidate the filter plugin can choose to keep or drop.
Fields
upstream_id: Box<str>name: Box<str>kind: Box<str>observed_at_unix_secs: u64predicted_cache_read_tokens: u32plan_capacity_ratio: f64organization_type: Box<str>rate_limit_tier: Box<str>seat_tier: Box<str>Trait Implementations
Sourceimpl Archive for UpstreamCandidate
impl Archive for UpstreamCandidate
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedUpstreamCandidate
type Archived = ArchivedUpstreamCandidate
The archived representation of this type. Read more
Sourcetype Resolver = UpstreamCandidateResolver
type Resolver = UpstreamCandidateResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for UpstreamCandidate
impl Clone for UpstreamCandidate
Sourcefn clone(&self) -> UpstreamCandidate
fn clone(&self) -> UpstreamCandidate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpstreamCandidate
impl Debug for UpstreamCandidate
Sourceimpl<__D: Fallible + ?Sized> Deserialize<UpstreamCandidate, __D> for Archived<UpstreamCandidate>
impl<__D: Fallible + ?Sized> Deserialize<UpstreamCandidate, __D> for Archived<UpstreamCandidate>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<UpstreamCandidate, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<UpstreamCandidate, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl WireSchema for UpstreamCandidate
impl WireSchema for UpstreamCandidate
const FINGERPRINT: [u8; 32]
const DESCRIPTOR: &'static str = "UpstreamCandidate{kind:Box<str>,name:Box<str>,observed_at_unix_secs:u64,organization_type:Box<str>,plan_capacity_ratio:f64,predicted_cache_read_tokens:u32,rate_limit_tier:Box<str>,seat_tier:Box<str>,upstream_id:Box<str>}"