pub struct UpstreamCandidateRef<'a> {
pub upstream_id: &'a str,
pub name: &'a str,
pub kind: &'a str,
pub observed_at_unix_secs: u64,
pub predicted_cache_read_tokens: u32,
pub plan_capacity_ratio: f64,
pub organization_type: &'a str,
pub rate_limit_tier: &'a str,
pub seat_tier: &'a str,
}Expand description
Borrowed mirror of UpstreamCandidate.
Fields
upstream_id: &'a strname: &'a strkind: &'a strobserved_at_unix_secs: u64predicted_cache_read_tokens: u32plan_capacity_ratio: f64organization_type: &'a strrate_limit_tier: &'a strseat_tier: &'a strTrait Implementations
Sourceimpl<'a> Archive for UpstreamCandidateRef<'a>
impl<'a> Archive for UpstreamCandidateRef<'a>
Sourcetype Archived = ArchivedUpstreamCandidateRef<'a>
type Archived = ArchivedUpstreamCandidateRef<'a>
The archived representation of this type. Read more
Sourcetype Resolver = UpstreamCandidateRefResolver<'a>
type Resolver = UpstreamCandidateRefResolver<'a>
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl<'a, __S: Fallible + ?Sized> Serialize<__S> for UpstreamCandidateRef<'a>where
InlineAsBox: SerializeWith<&'a str, __S>,
u64: Serialize<__S>,
u32: Serialize<__S>,
f64: Serialize<__S>,
impl<'a, __S: Fallible + ?Sized> Serialize<__S> for UpstreamCandidateRef<'a>where
InlineAsBox: SerializeWith<&'a str, __S>,
u64: Serialize<__S>,
u32: Serialize<__S>,
f64: Serialize<__S>,
impl<'a> WireSchema for UpstreamCandidateRef<'a>
impl<'a> WireSchema for UpstreamCandidateRef<'a>
const FINGERPRINT: [u8; 32]
const DESCRIPTOR: &'static str = "UpstreamCandidateRef{kind:&str,name:&str,observed_at_unix_secs:u64,organization_type:&str,plan_capacity_ratio:f64,predicted_cache_read_tokens:u32,rate_limit_tier:&str,seat_tier:&str,upstream_id:&str}"